@@ -11,18 +11,21 @@ from wpdatautil.timeit import Timer
 _COMPRESS_LEVEL = 6
 _INVERSE_PI = 1 / math.pi
 _CPU_COUNT_SCALER = (2 ** 30) ** _INVERSE_PI
-_MAX_USABLE_CPU_COUNT = multiprocessing.cpu_count() * 0.95
 
 log = logging.getLogger(__name__)
 
 
 def _num_threads(num_bytes: int) -> int:
     """Return the number of threads to use for compression or decompression."""
-    return max(1, math.floor(min(_CPU_COUNT_SCALER, num_bytes ** _INVERSE_PI) * _MAX_USABLE_CPU_COUNT / _CPU_COUNT_SCALER))
+    max_usable_cpu_count = multiprocessing.cpu_count() * 0.95
+    return max(1, math.floor(min(_CPU_COUNT_SCALER, num_bytes ** _INVERSE_PI) * max_usable_cpu_count / _CPU_COUNT_SCALER))
 
 
 def compress(uncompressed: bytes, description: str = "blob") -> bytes:
-    """Compress the given bytes."""
+    """Compress the given bytes in parallel.
+
+    The number of compression threads is determined automatically based on the input size and the CPU count.
+    """
     len_uncompressed = len(uncompressed)
     len_uncompressed_formatted = format_size(len_uncompressed)
     num_threads = _num_threads(len_uncompressed)
@@ -34,5 +37,8 @@ def compress(uncompressed: bytes, description: str = "blob") -> bytes:
 
 
 def decompress(compressed: bytes) -> bytes:
-    """Decompress the given bytes."""
+    """Decompress the given bytes in parallel.
+
+    The number of decompression threads is determined automatically based on the input size and the CPU count.
+    """
     return mgzip.decompress(compressed, thread=_num_threads(len(compressed)))
